2. How to create a Cart modifier — Django Shop v0.0.0 documentation

### Navigation

- index
- next |
- previous |
- Django Shop v0.0.0 documentation »

# 2. How to create a Cart modifier

Cart modifiers are simple plugins that allow you to define rules according to which carts should be modified (and in what order).

Generally, this is how you implement a “bulk rebate” module, for instance.

### Navigation

- index
- next |
- previous |
- Django Shop v0.0.0 documentation »